/*
 * Copyright (C) Sureshot 2002
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Review history:
 *
 */

package se.bysoft.sureshot.util.reporter;

import javax.swing.JFrame;
import javax.swing.JOptionPane;

/**
 * Displays messages in a message box.
 *
 * @author Roger Karlsson
 * @since  February 26, 2002
 */
public class MessageBoxReporter implements ErrorReporter, InfoReporter
{
    /**
     * Creates a message box reporter.
     *
     * @param frame  The frame that owns the message box.
     * @param title  The title of the message box.
     */
    public MessageBoxReporter(final JFrame frame,
                              final String title)
    {
        _frame = frame;
        _title = title;
    }
    
    /**
     * See the interface.
     */
    public void reportError(final String message)
    {
        JOptionPane.showMessageDialog(_frame,
                                      message,
                                      _title,
                                      JOptionPane.ERROR_MESSAGE);
    }
    
    /**
     * See the interface.
     */
    public void reportInfo(final String message)
    {
        JOptionPane.showMessageDialog(_frame,
                                      message,
                                      _title,
                                      JOptionPane.INFORMATION_MESSAGE);
    }
    
    private final JFrame _frame;
    private final String _title;
}
